--- nagios-plugins-HEAD-200501200547/plugins/check_swap.c	2005-01-19 19:14:47.000000000 -0200
+++ check_swap.c	2005-01-20 14:37:15.000000000 -0200
@@ -21,20 +21,20 @@
  *
  * Copyright (c) 2000 Karl DeBisschop (kdebisschop@users.sourceforge.net)
  *
- * $Id: check_swap.c,v 1.47 2005/01/19 21:14:47 tonvoon Exp $
+ * $Id: check_swap.c,v 1.31 2004/08/23 21:18:12 tonvoon Exp $
  *
  *****************************************************************************/
 
-const char *progname = "check_swap";
-const char *revision = "$Revision: 1.47 $";
-const char *copyright = "2000-2004";
-const char *email = "nagiosplug-devel@lists.sourceforge.net";
-
 #include "common.h"
 #include "popen.h"
 #include "utils.h"
 
-int check_swap (int usp, float free_swap);
+const char *progname = "check_swap";
+const char *revision = "$Revision: 1.31 $";
+const char *copyright = "2000-2003";
+const char *email = "nagiosplug-devel@lists.sourceforge.net";
+
+int check_swap (int usp, unsigned int free_swap);
 int process_arguments (int argc, char **argv);
 int validate_arguments (void);
 void print_usage (void);
@@ -42,8 +42,8 @@
 
 int warn_percent = 0;
 int crit_percent = 0;
-float warn_size = 0;
-float crit_size = 0;
+unsigned int warn_size = 0;
+unsigned int crit_size = 0;
 int verbose;
 int allswaps;
 
@@ -51,15 +51,22 @@
 main (int argc, char **argv)
 {
 	int percent_used, percent;
-	float total_swap = 0, used_swap = 0, free_swap = 0;
-	float dsktotal = 0, dskused = 0, dskfree = 0, tmp = 0;
-	int result = STATE_UNKNOWN;
+
+#if _AIX
+	unsigned int total_swap = 0, used_swap = 0, free_swap = 0;
+	unsigned int dsktotal = 0, dskused = 0, dskfree = 0, tmp = 0;
+#else
+	unsigned long long total_swap = 0, used_swap = 0, free_swap = 0;
+        unsigned long long dsktotal = 0, dskused = 0, dskfree = 0, tmp = 0;
+
+#endif
+	int result = STATE_OK;
 	char input_buffer[MAX_INPUT_BUFFER];
 	char *perf;
+	int conv_factor = SWAP_CONVERSION;
 #ifdef HAVE_PROC_MEMINFO
 	FILE *fp;
 #else
-	int conv_factor = SWAP_CONVERSION;
 # ifdef HAVE_SWAP
 	char *temp_buffer;
 	char *swap_command;
@@ -89,13 +96,13 @@
 	tmp_status = strdup ("");
 	perf = strdup ("");
 
-	if (process_arguments (argc, argv) == ERROR)
-		usage4 (_("Could not parse arguments"));
+	if (process_arguments (argc, argv) != OK)
+		usage (_("Invalid command arguments supplied\n"));
 
 #ifdef HAVE_PROC_MEMINFO
 	fp = fopen (PROC_MEMINFO, "r");
 	while (fgets (input_buffer, MAX_INPUT_BUFFER - 1, fp)) {
-		if (sscanf (input_buffer, "%*[S]%*[w]%*[a]%*[p]%*[:] %f %f %f", &dsktotal, &dskused, &dskfree) == 3) {
+		if (sscanf (input_buffer, "%*[S]%*[w]%*[a]%*[p]%*[:] %llu %llu %llu", &dsktotal, &dskused, &dskfree) == 3) {
 			dsktotal = dsktotal / 1048576;
 			dskused = dskused / 1048576;
 			dskfree = dskfree / 1048576;
@@ -109,10 +116,10 @@
 					percent = 100 * (((double) dskused) / ((double) dsktotal));
 				result = max_state (result, check_swap (percent, dskfree));
 				if (verbose)
-					asprintf (&status, "%s [%.0f (%d%%)]", status, dskfree, 100 - percent);
+					asprintf (&status, "%s [%llu (%d%%)]", status, dskfree, 100 - percent);
 			}
 		}
-		else if (sscanf (input_buffer, "%*[S]%*[w]%*[a]%*[p]%[TotalFre]%*[:] %f %*[k]%*[B]", str, &tmp)) {
+		else if (sscanf (input_buffer, "%*[S]%*[w]%*[a]%*[p]%[TotalFre]%*[:] %llu %*[k]%*[B]", str, &tmp)) {
 			if (strcmp ("Total", str) == 0) {
 				dsktotal = tmp / 1024;
 			}
@@ -136,7 +143,7 @@
 #  ifdef _AIX
 	if (!allswaps) {
 		asprintf(&swap_command, "%s", "/usr/sbin/lsps -s");
-		asprintf(&swap_format, "%s", "%f%*s %f");
+		asprintf(&swap_format, "%s", "%d%*s %d");
 		conv_factor = 1;
 	}
 #  endif
@@ -180,7 +187,7 @@
 		free_swap = total_swap * (100 - used_swap) /100;
 		used_swap = total_swap - free_swap;
 		if (verbose >= 3)
-			printf (_("total=%.0f, used=%.0f, free=%.0f\n"), total_swap, used_swap, free_swap);
+			printf (_("total=%d, used=%d, free=%d\n"), total_swap, used_swap, free_swap);
 	} else {
 #  endif
 		while (fgets (input_buffer, MAX_INPUT_BUFFER - 1, child_process)) {
@@ -194,7 +201,7 @@
 			dskfree = dskfree / conv_factor;
 #  endif
 			if (verbose >= 3)
-				printf (_("total=%.0f, free=%.0f\n"), dsktotal, dskfree);
+				printf (_("total=%d, free=%d\n"), dsktotal, dskfree);
 
 			dskused = dsktotal - dskfree;
 			total_swap += dsktotal;
@@ -204,7 +211,7 @@
 				percent = 100 * (((double) dskused) / ((double) dsktotal));
 				result = max_state (result, check_swap (percent, dskfree));
 				if (verbose)
-					asprintf (&status, "%s [%.0f (%d%%)]", status, dskfree, 100 - percent);
+					asprintf (&status, "%s [%llu (%d%%)]", status, dskfree, 100 - percent);
 			}
 		}
 #  ifdef _AIX
@@ -239,23 +246,20 @@
 	/* and now, tally 'em up */
 	swapctl_res=swapctl(SC_LIST, tbl);
 	if(swapctl_res < 0){
-		perror(_("swapctl failed: "));
+		perror("swapctl failed: ");
 		result = STATE_WARNING;
 	}
 
 	for(i=0;i<nswaps;i++){
-		dsktotal = (float) tbl->swt_ent[i].ste_pages / SWAP_CONVERSION;
-		dskfree = (float) tbl->swt_ent[i].ste_free /  SWAP_CONVERSION;
+		dsktotal = tbl->swt_ent[i].ste_pages / SWAP_CONVERSION;
+		dskfree = tbl->swt_ent[i].ste_free /  SWAP_CONVERSION;
 		dskused = ( dsktotal - dskfree );
 
-		if (verbose >= 3)
-			printf ("dsktotal=%.0f dskfree=%.0f dskused=%.0f\n", dsktotal, dskfree, dskused);
-
 		if(allswaps && dsktotal > 0){
 			percent = 100 * (((double) dskused) / ((double) dsktotal));
 			result = max_state (result, check_swap (percent, dskfree));
 			if (verbose) {
-				asprintf (&status, "%s [%.0f (%d%%)]", status, dskfree, 100 - percent);
+				asprintf (&status, "%s [%d (%d%%)]", status, (int)dskfree, 100 - percent);
 			}
 		}
 
@@ -281,20 +285,20 @@
 	/* and now, tally 'em up */
 	swapctl_res=swapctl(SWAP_STATS, ent, nswaps);
 	if(swapctl_res < 0){
-		perror(_("swapctl failed: "));
+		perror("swapctl failed: ");
 		result = STATE_WARNING;
 	}
 
 	for(i=0;i<nswaps;i++){
-		dsktotal = (float) ent->se_nblks / conv_factor;
-		dskused = (float) ent->se_inuse / conv_factor;
+		dsktotal = ent->se_nblks / conv_factor;
+		dskused = ent->se_inuse / conv_factor;
 		dskfree = ( dsktotal - dskused );
 
 		if(allswaps && dsktotal > 0){
 			percent = 100 * (((double) dskused) / ((double) dsktotal));
 			result = max_state (result, check_swap (percent, dskfree));
 			if (verbose) {
-				asprintf (&status, "%s [%.0f (%d%%)]", status, dskfree, 100 - percent);
+				asprintf (&status, "%s [%d (%d%%)]", status, (int)dskfree, 100 - percent);
 			}
 		}
 
@@ -314,23 +318,24 @@
 	percent_used = 100 * ((double) used_swap) / ((double) total_swap);
 	result = max_state (result, check_swap (percent_used, free_swap));
 	/* broken into two steps because of funkiness with builtin asprintf */
-	asprintf (&tmp_status, _(" %d%% free (%.0f MB out of %.0f MB)"),
+	asprintf (&tmp_status, _(" %d%% free (%llu MB out of %llu MB)"),
 						(100 - percent_used), free_swap, total_swap);
 	asprintf (&status, "%s%s", tmp_status, status);
 
-	asprintf (&perf, "%s", perfdata ("swap", (long) free_swap, "MB",
-		TRUE, (long) max (warn_size/1024, warn_percent/100.0*total_swap),
-		TRUE, (long) max (crit_size/1024, crit_percent/100.0*total_swap),
+	asprintf (&perf, "%s", perfdata ("swap", free_swap, "MB",
+		TRUE, max (warn_size/1024, warn_percent/100.0*total_swap),
+		TRUE, max (crit_size/1024, crit_percent/100.0*total_swap),
 		TRUE, 0,
-		TRUE, (long) total_swap));
+		TRUE, total_swap));
 	printf ("SWAP %s:%s |%s\n", state_text (result), status, perf);
 	return result;
 }
 
 
 
+
 int
-check_swap (int usp, float free_swap)
+check_swap (int usp, unsigned int free_swap)
 {
 	int result = STATE_UNKNOWN;
 	free_swap = free_swap * 1024;		/* Convert back to bytes as warn and crit specified in bytes */
@@ -348,7 +353,6 @@
 }
 
 
-
 /* process command-line arguments */
 int
 process_arguments (int argc, char **argv)
@@ -378,12 +382,12 @@
 		switch (c) {
 		case 'w':									/* warning size threshold */
 			if (is_intnonneg (optarg)) {
-				warn_size = (float) atoi (optarg);
+				warn_size = atoi (optarg);
 				break;
 			}
 			else if (strstr (optarg, ",") &&
 							 strstr (optarg, "%") &&
-							 sscanf (optarg, "%.0f,%d%%", &warn_size, &warn_percent) == 2) {
+							 sscanf (optarg, "%llu,%d%%", &warn_size, &warn_percent) == 2) {
 				break;
 			}
 			else if (strstr (optarg, "%") &&
@@ -391,16 +395,16 @@
 				break;
 			}
 			else {
-				usage4 (_("Warning threshold must be integer or percentage!"));
+				usage (_("Warning threshold must be integer or percentage!\n"));
 			}
 		case 'c':									/* critical size threshold */
 			if (is_intnonneg (optarg)) {
-				crit_size = (float) atoi (optarg);
+				crit_size = atoi (optarg);
 				break;
 			}
 			else if (strstr (optarg, ",") &&
 							 strstr (optarg, "%") &&
-							 sscanf (optarg, "%.0f,%d%%", &crit_size, &crit_percent) == 2) {
+							 sscanf (optarg, "%llu,%d%%", &crit_size, &crit_percent) == 2) {
 				break;
 			}
 			else if (strstr (optarg, "%") &&
@@ -408,7 +412,7 @@
 				break;
 			}
 			else {
-				usage4 (_("Critical threshold must be integer or percentage!"));
+				usage (_("Critical threshold must be integer or percentage!\n"));
 			}
 		case 'a':									/* all swap */
 			allswaps = TRUE;
@@ -423,7 +427,7 @@
 			print_help ();
 			exit (STATE_OK);
 		case '?':									/* error */
-			usage2 (_("Unknown argument"), optarg);
+			usage (_("Invalid argument\n"));
 		}
 	}
 
@@ -441,7 +445,7 @@
 	if (c == argc)
 		return validate_arguments ();
 	if (warn_size == 0 && is_intnonneg (argv[c]))
-		warn_size = (float) atoi (argv[c++]);
+		warn_size = atoi (argv[c++]);
 
 	if (c == argc)
 		return validate_arguments ();
@@ -453,6 +457,8 @@
 
 
 
+
+
 int
 validate_arguments (void)
 {
@@ -461,18 +467,21 @@
 		return ERROR;
 	}
 	else if (warn_percent < crit_percent) {
-		usage4 
-			(_("Warning percentage should be more than critical percentage"));
+		usage
+			(_("Warning percentage should be more than critical percentage\n"));
 	}
 	else if (warn_size < crit_size) {
-		usage4
-			(_("Warning free space should be more than critical free space"));
+		usage
+			(_("Warning free space should be more than critical free space\n"));
 	}
 	return OK;
 }
 
 
 
+
+
+
 void
 print_help (void)
 {
@@ -480,7 +489,7 @@
 
 	printf (_(COPYRIGHT), copyright, email);
 
-	printf (_("Check swap space on local machine.\n\n"));
+	printf (_("Check swap space on local server.\n\n"));
 
 	print_usage ();
 
@@ -512,10 +521,14 @@
 
 
 
+
 void
 print_usage (void)
 {
-	printf ("\
-Usage: %s [-av] -w <percent_free>%% -c <percent_free>%%\n\
-       %s [-av] -w <bytes_free> -c <bytes_free>\n", progname, progname);
+	printf (_("Usage:\n\
+ %s [-av] -w <percent_free>%% -c <percent_free>%%\n\
+ %s [-av] -w <bytes_free> -c <bytes_free>\n\
+ %s (-h | --help) for detailed help\n\
+ %s (-V | --version) for version information\n"),
+	        progname, progname, progname, progname);
 }
